GridItem<T> class

Constructors

GridItem({required String image, required String id, required String title, required T data, bool disabled = false})

Properties

data → T
final
disabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
image → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

copyWith({String? image, String? id, String? title, bool? disabled, T? data}) → GridItem<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited