Injected class

Constructors

Injected({required String namespace, required String injectedId})
Injected.fromJson(Map<String, dynamic> json)
factory
Injected.fromRawJson(String str)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
injectedId → String
final
namespace → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? namespace, String? injectedId}) → Injected
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited