Listing class

Constructors

Listing({required String id, required String name, required String homepage, required String imageId, required int order, String? mobileLink, String? desktopLink, String? webappLink, String? appStore, String? playStore, String? rdns, List<Injected>? injected})
const
Listing.fromJson(Object? json)
factory
Listing.fromRawJson(String str)
factory

Properties

appStore → String?
final
final
hashCode → int
The hash code for this object.
no setterinherited
homepage → String
final
id → String
final
imageId → String
final
injected → List<Injected>?
final
final
name → String
final
order → int
final
playStore → String?
final
rdns → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final

Methods

copyWith({String? id, String? name, String? homepage, String? imageId, int? order, String? mobileLink, String? desktopLink, String? webappLink, String? appStore, String? playStore, String? rdns, List<Injected>? injected}) → Listing
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited