W3MChainInfo class

Annotations
  • @freezed

Constructors

W3MChainInfo({required String chainName, required String chainId, required String namespace, required String chainIcon, required String tokenName, required Map<String, RequiredNamespace> requiredNamespaces, required Map<String, RequiredNamespace> optionalNamespaces, required String rpcUrl, @Default.new(EVMService()) ILedgerService ledgerService})
factory

Properties

chainIcon String
no setterinherited
chainId String
no setterinherited
chainName String
no setterinherited
copyWith → $W3MChainInfoCopyWith<W3MChainInfo>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ledgerService ILedgerService
no setterinherited
namespace String
no setterinherited
optionalNamespaces Map<String, RequiredNamespace>
no setterinherited
requiredNamespaces Map<String, RequiredNamespace>
no setterinherited
rpcUrl String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenName String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited