AnalyticsService class

Implemented types

Constructors

AnalyticsService({required String projectId, bool? enableAnalytics})

Properties

enableAnalytics → bool?
final
events → Stream
final
hashCode → int
The hash code for this object.
no setterinherited
projectId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchAnalyticsConfig() → Future<bool>
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendEvent(AnalyticsEvent analyticsEvent) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited