EmailVerificationCodeSent class

Implemented types

Constructors

EmailVerificationCodeSent()

Properties

event → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
properties → Map<String, dynamic>?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited