CoinbaseData class

Constructors

CoinbaseData({required String address, required String chainName, required int chainId, ConnectionMetadata? self, ConnectionMetadata? peer})
CoinbaseData.fromJson(Map<String, dynamic> json)
factory

Properties

address ↔ String
getter/setter pair
chainId ↔ int
getter/setter pair
chainName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
peer ↔ ConnectionMetadata?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
self ↔ ConnectionMetadata?
getter/setter pair

Methods

copytWith({String? address, String? chainName, int? chainId, ConnectionMetadata? self, ConnectionMetadata? peer}) → CoinbaseData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited