MagicService class

Implemented types

Constructors

MagicService({required IWeb3App web3app, bool enabled = false})

Properties

controller → WebViewController
no setter
email → ValueNotifier<String>
final
hashCode → int
The hash code for this object.
no setterinherited
isConnected → ValueNotifier<bool>
final
isEnabled → ValueNotifier<bool>
final
isReady → ValueNotifier<bool>
final
isTimeout → ValueNotifier<bool>
final
metadata → ConnectionMetadata
no setteroverride
newEmail → ValueNotifier<String>
final
onMagicConnect ↔ Event<MagicConnectEvent>
getter/setter pairoverride-getter
onMagicError ↔ Event<MagicErrorEvent>
getter/setter pairoverride-getter
onMagicLoginRequest ↔ Event<MagicSessionEvent>
getter/setter pairoverride-getter
onMagicLoginSuccess ↔ Event<MagicLoginEvent>
getter/setter pairoverride-getter
onMagicRpcRequest ↔ Event<MagicRequestEvent>
getter/setter pairoverride-getter
onMagicUpdate ↔ Event<MagicSessionEvent>
getter/setter pairoverride-getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
step → ValueNotifier<EmailLoginStep>
final
webview → WebViewWidget
no setter

Methods

connectEmail({required String value, String? chainId}) → Future<void>
override
connectOtp({required String otp}) → Future<void>
override
disconnect() → Future<bool>
override
getChainId() → Future<void>
override
getUser({String? chainId}) → Future<void>
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request({String? chainId, required SessionRequestParams request}) → Future
override
setEmail(String value) → void
override
setNewEmail(String value) → void
override
switchNetwork({required String chainId}) → Future<void>
override
syncTheme(Web3ModalTheme? theme) → Future<void>
override
toString() → String
A string representation of this object.
inherited
updateEmail({required String value}) → Future<void>
override
updateEmailPrimaryOtp({required String otp}) → Future<void>
override
updateEmailSecondaryOtp({required String otp}) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited