FrameMessage class

Constructors

FrameMessage({MessageData? data, String? origin})
FrameMessage.fromJson(Map<String, dynamic> json)
factory
FrameMessage.fromRawJson(String str)
factory

Properties

data → MessageData?
final
hashCode → int
The hash code for this object.
no setterinherited
isValidData → bool
no setter
isValidOrigin → bool
no setter
origin → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageData? data, String? origin}) → FrameMessage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited