MessageData class

Implementers

Constructors

MessageData({String? type, dynamic payload})
MessageData.fromJson(Map<String, dynamic> json)
factory
MessageData.fromRawJson(String str)
factory

Properties

connectEmailError → bool
no setter
connectEmailSuccess → bool
no setter
connectOtpError → bool
no setter
connectOtpSuccess → bool
no setter
getChainIdError → bool
no setter
getChainIdSuccess → bool
no setter
getUserError → bool
no setter
getUserSuccess → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isConnectError → bool
no setter
isConnectSuccess → bool
no setter
payload → dynamic
final
rpcRequestError → bool
no setter
rpcRequestSuccess → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionUpdate → bool
no setter
signOutError → bool
no setter
signOutSuccess → bool
no setter
switchNetworkError → bool
no setter
switchNetworkSuccess → bool
no setter
syncDataSuccess → bool
no setter
syncThemeSuccess → bool
no setter
type → String?
final
updateEmailError → bool
no setter
updateEmailPrimaryOtpError → bool
no setter
updateEmailPrimarySuccess → bool
no setter
updateEmailSecondaryOtpError → bool
no setter
updateEmailSecondarySuccess → bool
no setter
updateEmailSuccess → bool
no setter

Methods

copyWith({String? type, dynamic payload}) → MessageData
getPayloadMapKey<T>(String key) → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited