UpdateEmail class

Inheritance

Constructors

UpdateEmail({required String email})

Properties

connectEmailError → bool
no setterinherited
connectEmailSuccess → bool
no setterinherited
connectOtpError → bool
no setterinherited
connectOtpSuccess → bool
no setterinherited
email → String
final
getChainIdError → bool
no setterinherited
getChainIdSuccess → bool
no setterinherited
getUserError → bool
no setterinherited
getUserSuccess → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isConnectError → bool
no setterinherited
isConnectSuccess → bool
no setterinherited
payload → dynamic
finalinherited
rpcRequestError → bool
no setterinherited
rpcRequestSuccess → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionUpdate → bool
no setterinherited
signOutError → bool
no setterinherited
signOutSuccess → bool
no setterinherited
switchNetworkError → bool
no setterinherited
switchNetworkSuccess → bool
no setterinherited
syncDataSuccess → bool
no setterinherited
syncThemeSuccess → bool
no setterinherited
type → String?
finalinherited
updateEmailError → bool
no setterinherited
updateEmailPrimaryOtpError → bool
no setterinherited
updateEmailPrimarySuccess → bool
no setterinherited
updateEmailSecondaryOtpError → bool
no setterinherited
updateEmailSecondarySuccess → bool
no setterinherited
updateEmailSuccess → bool
no setterinherited

Methods

copyWith({String? type, dynamic payload}) → MessageData
inherited
getPayloadMapKey<T>(String key) → T
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toRawJson() → String
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited