NetworkService class

Implemented types

Constructors

NetworkService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialized ↔ ValueNotifier<bool>
getter/setter pairoverride
itemList ↔ ValueNotifier<List<GridItem<W3MChainInfo>>>
getter/setter pairoverride
itemListComplete ↔ List<GridItem<W3MChainInfo>>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

filterList({String? query}) → void
override
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited