Web3ModalThemeData class

Annotations
  • @freezed

Constructors

Web3ModalThemeData({@Default.new(Web3ModalColors.lightMode) Web3ModalColors lightColors, @Default.new(Web3ModalColors.darkMode) Web3ModalColors darkColors, @Default.new(Web3ModalTextStyles.textStyle) Web3ModalTextStyles textStyles, @Default.new(Web3ModalRadiuses()) Web3ModalRadiuses radiuses})
const
factory

Properties

copyWith → $Web3ModalThemeDataCopyWith<Web3ModalThemeData>
no setterinherited
darkColors → Web3ModalColors
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
lightColors → Web3ModalColors
no setterinherited
radiuses → Web3ModalRadiuses
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyles → Web3ModalTextStyles
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited