IPlatformUtils class abstract

Implementers

Constructors

IPlatformUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canDetectInstalledApps() → bool
getPlatformExact() → PlatformExact
getPlatformType() → PlatformType
isBottomSheet() → bool
isLongBottomSheet(Orientation orientation) → bool
isMobileWidth(double width) → bool
isTablet(BuildContext context) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited