PlatformUtils class

Inheritance

Constructors

PlatformUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canDetectInstalledApps() → bool
override
getPlatformExact() → PlatformExact
override
getPlatformType() → PlatformType
override
isBottomSheet() → bool
override
isLongBottomSheet(Orientation orientation) → bool
override
isMobileWidth(double width) → bool
override
isTablet(BuildContext context) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited