PairingMetadata class

Annotations
  • @freezed

Constructors

PairingMetadata({required String name, required String description, required String url, required List<String> icons, String? verifyUrl, Redirect? redirect})
const
factory
PairingMetadata.empty()
factory
PairingMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PairingMetadataCopyWith<PairingMetadata>
no setterinherited
description → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
icons → List<String>
no setterinherited
name → String
no setterinherited
redirect → Redirect?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
no setterinherited
verifyUrl → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited