WidgetStack class
Methods
-
addDefault()
→ void
-
Adds a default widget to the stack based on platform.
override
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
canPop()
→ bool
-
Checks if the stack can be popped.
override
-
clear()
→ void
-
Clears the stack.
override
-
containsKey(Key key)
→ bool
-
Checks if the stack contains a widget with the given key.
override
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
getCurrent()
→ Widget
-
Returns the current widget.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
pop()
→ void
-
Removes a widget from the stack.
override
-
popAllAndPush(Widget widget, {bool renderScreen = false})
→ void
-
override
-
popUntil(Key key)
→ void
-
Removes widgets from the stack until the given type of widget is found.
override
-
push(Widget widget, {bool renderScreen = false, AnalyticsEvent? event})
→ void
-
Pushes a widget to the stack.
override
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited